@@ -5,10 +5,11 @@ import numpy as np
 import requests
 from bs4 import BeautifulSoup
 
+""" The XML is the hmrc XML"""
 # http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-0222.XML
 
 def hmrc_to_dataframe(month, year):
-    url = f"http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-{month}{year[2:]}.XML"
+    url = f"http://www.hmrc.gov.uk/softwaredevelopers/rates/exrates-monthly-{month.zfill(2)}{year[2:]}.XML"
     document = requests.get(url)
     soup = BeautifulSoup(document.content, "xml")
     countryName = soup.find_all('countryName')
@@ -31,4 +32,4 @@ def hmrc_to_dataframe(month, year):
     exchange_rate_df['reported_month_year'] = url[-8:-4]
     exchange_rate_df['exchageRate_starDate'] = pd.to_datetime(
         exchange_rate_df['reported_month_year'], format="%m%y")
-    return exchange_rate_df
\ No newline at end of file
+    return exchange_rate_df
